@@ -32,13 +32,6 @@
 
 #define MAX_HEIGHT              4096
 
-
-static const GstElementDetails gst_pngenc_details =
-GST_ELEMENT_DETAILS ("PNG image encoder",
-    "Codec/Encoder/Image",
-    "Encode a video frame to a .png image",
-    "Jeremy SIMON <jsimon13@yahoo.fr>");
-
 GST_DEBUG_CATEGORY_STATIC (pngenc_debug);
 #define GST_CAT_DEFAULT pngenc_debug
 
@@ -67,7 +60,7 @@ GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("image/png, "
         "width = (int) [ 16, 4096 ], "
-        "height = (int) [ 16, 4096 ], " "framerate = (fraction) [ 0.0, MAX ]")
+        "height = (int) [ 16, 4096 ], " "framerate = (fraction) [ 0, MAX ]")
     );
 
 static GstStaticPadTemplate pngenc_sink_template =
@@ -109,7 +102,10 @@ gst_pngenc_base_init (gpointer g_class)
       (element_class, gst_static_pad_template_get (&pngenc_sink_template));
   gst_element_class_add_pad_template
       (element_class, gst_static_pad_template_get (&pngenc_src_template));
-  gst_element_class_set_details (element_class, &gst_pngenc_details);
+  gst_element_class_set_details_simple (element_class, "PNG image encoder",
+      "Codec/Encoder/Image",
+      "Encode a video frame to a .png image",
+      "Jeremy SIMON <jsimon13@yahoo.fr>");
 }
 
 static void
@@ -224,8 +220,7 @@ user_write_data (png_structp png_ptr, png_bytep data, png_uint_32 length)
 
   if (pngenc->written + length >= GST_BUFFER_SIZE (pngenc->buffer_out)) {
     GST_ERROR_OBJECT (pngenc, "output buffer bigger than the input buffer!?");
-    /* yuck */
-    longjmp (pngenc->png_struct_ptr->jmpbuf, 1);
+    png_error (png_ptr, "output buffer bigger than the input buffer!?");
 
     /* never reached */
     return;
@@ -270,7 +265,7 @@ gst_pngenc_chain (GstPad * pad, GstBuffer * buf)
   }
 
   /* non-0 return is from a longjmp inside of libpng */
-  if (setjmp (pngenc->png_struct_ptr->jmpbuf) != 0) {
+  if (setjmp (png_jmpbuf (pngenc->png_struct_ptr)) != 0) {
     gst_buffer_unref (buf);
     png_destroy_write_struct (&pngenc->png_struct_ptr, &pngenc->png_info_ptr);
     GST_ELEMENT_ERROR (pngenc, LIBRARY, FAILED, (NULL),
