@@ -90,12 +90,6 @@ enum
   PROP_DEVICE_NAME
 };
 
-static const GstElementDetails gst_hdv1394src_details =
-GST_ELEMENT_DETAILS ("Firewire (1394) HDV video source",
-    "Source/Video",
-    "Source for MPEG-TS video data from firewire port",
-    "Edward Hervey <bilboed@bilboed.com>");
-
 static GstStaticPadTemplate src_factory = GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
@@ -149,7 +143,10 @@ gst_hdv1394src_base_init (gpointer g_class)
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&src_factory));
 
-  gst_element_class_set_details (element_class, &gst_hdv1394src_details);
+  gst_element_class_set_details_simple (element_class,
+      "Firewire (1394) HDV video source", "Source/Video",
+      "Source for MPEG-TS video data from firewire port",
+      "Edward Hervey <bilboed@bilboed.com>");
 }
 
 static void
@@ -796,7 +793,7 @@ gst_hdv1394src_uri_get_type (void)
 static gchar **
 gst_hdv1394src_uri_get_protocols (void)
 {
-  static gchar *protocols[] = { "hdv", NULL };
+  static gchar *protocols[] = { (char *) "hdv", NULL };
 
   return protocols;
 }
