@@ -39,8 +39,6 @@
 
 #include <string.h>
 #include <gst/base/gstbytereader.h>
-#include <gst/pbutils/descriptions.h>
-#include <gst/pbutils/pbutils.h>
 
 static GstStaticPadTemplate flv_sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
@@ -49,30 +47,16 @@ static GstStaticPadTemplate flv_sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     );
 
 static GstStaticPadTemplate audio_src_template =
-    GST_STATIC_PAD_TEMPLATE ("audio",
+GST_STATIC_PAD_TEMPLATE ("audio",
     GST_PAD_SRC,
     GST_PAD_SOMETIMES,
-    GST_STATIC_CAPS
-    ("audio/x-adpcm, layout = (string) swf, channels = (int) { 1, 2 }, rate = (int) { 5512, 11025, 22050, 44100 }; "
-        "audio/mpeg, mpegversion = (int) 1, layer = (int) 3, channels = (int) { 1, 2 }, rate = (int) { 5512, 8000, 11025, 22050, 44100 }, parsed = (boolean) TRUE; "
-        "audio/mpeg, mpegversion = (int) 4, framed = (boolean) TRUE; "
-        "audio/x-nellymoser, channels = (int) { 1, 2 }, rate = (int) { 5512, 8000, 11025, 16000, 22050, 44100 }; "
-        "audio/x-raw-int, endianness = (int) LITTLE_ENDIAN, channels = (int) { 1, 2 }, width = (int) 8, depth = (int) 8, rate = (int) { 5512, 11025, 22050, 44100 }, signed = (boolean) FALSE; "
-        "audio/x-raw-int, endianness = (int) LITTLE_ENDIAN, channels = (int) { 1, 2 }, width = (int) 16, depth = (int) 16, rate = (int) { 5512, 11025, 22050, 44100 }, signed = (boolean) TRUE; "
-        "audio/x-alaw, channels = (int) { 1, 2 }, rate = (int) { 5512, 11025, 22050, 44100 }; "
-        "audio/x-mulaw, channels = (int) { 1, 2 }, rate = (int) { 5512, 11025, 22050, 44100 }; "
-        "audio/x-speex, channels = (int) { 1, 2 }, rate = (int) { 5512, 11025, 22050, 44100 };")
-    );
+    GST_STATIC_CAPS_ANY);
 
 static GstStaticPadTemplate video_src_template =
-    GST_STATIC_PAD_TEMPLATE ("video",
+GST_STATIC_PAD_TEMPLATE ("video",
     GST_PAD_SRC,
     GST_PAD_SOMETIMES,
-    GST_STATIC_CAPS ("video/x-flash-video; "
-        "video/x-flash-screen; "
-        "video/x-vp6-flash; " "video/x-vp6-alpha; "
-        "video/x-h264, stream-format=avc;")
-    );
+    GST_STATIC_CAPS_ANY);
 
 GST_DEBUG_CATEGORY_STATIC (flvdemux_debug);
 #define GST_CAT_DEFAULT flvdemux_debug
@@ -84,9 +68,6 @@ GST_BOILERPLATE (GstFlvDemux, gst_flv_demux, GstElement, GST_TYPE_ELEMENT);
 /* 1 byte of tag type + 3 bytes of tag data size */
 #define FLV_TAG_TYPE_SIZE 4
 
-/* two seconds - consider pts are resynced to another base if this different */
-#define RESYNC_THRESHOLD 2000
-
 static gboolean flv_demux_handle_seek_push (GstFlvDemux * demux,
     GstEvent * event);
 static gboolean gst_flv_demux_handle_seek_pull (GstFlvDemux * demux,
@@ -107,10 +88,6 @@ gst_flv_demux_parse_and_add_index_entry (GstFlvDemux * demux, GstClockTime ts,
       "adding key=%d association %" GST_TIME_FORMAT "-> %" G_GUINT64_FORMAT,
       keyframe, GST_TIME_ARGS (ts), pos);
 
-  /* if upstream is not seekable there is no point in building an index */
-  if (!demux->upstream_seekable)
-    return;
-
   /* entry may already have been added before, avoid adding indefinitely */
   entry = gst_index_get_assoc_entry (demux->index, demux->index_id,
       GST_INDEX_LOOKUP_EXACT, GST_ASSOCIATION_FLAG_NONE, GST_FORMAT_BYTES, pos);
@@ -121,11 +98,11 @@ gst_flv_demux_parse_and_add_index_entry (GstFlvDemux * demux, GstClockTime ts,
     gboolean key;
 
     gst_index_entry_assoc_map (entry, GST_FORMAT_TIME, &time);
-    key = ! !(GST_INDEX_ASSOC_FLAGS (entry) & GST_ASSOCIATION_FLAG_KEY_UNIT);
+    key = !!(GST_INDEX_ASSOC_FLAGS (entry) & GST_ASSOCIATION_FLAG_KEY_UNIT);
     GST_LOG_OBJECT (demux, "position already mapped to time %" GST_TIME_FORMAT
         ", keyframe %d", GST_TIME_ARGS (time), key);
     /* there is not really a way to delete the existing one */
-    if (time != ts || key != ! !keyframe)
+    if (time != ts || key != !!keyframe)
       GST_DEBUG_OBJECT (demux, "metadata mismatch");
 #endif
     return;
@@ -137,9 +114,8 @@ gst_flv_demux_parse_and_add_index_entry (GstFlvDemux * demux, GstClockTime ts,
   associations[1].value = pos;
 
   gst_index_add_associationv (demux->index, demux->index_id,
-      (keyframe) ? GST_ASSOCIATION_FLAG_KEY_UNIT :
-      GST_ASSOCIATION_FLAG_DELTA_UNIT, 2,
-      (const GstIndexAssociation *) &associations);
+      (keyframe) ? GST_ASSOCIATION_FLAG_KEY_UNIT : GST_ASSOCIATION_FLAG_NONE,
+      2, (const GstIndexAssociation *) &associations);
 
   if (pos > demux->index_max_pos)
     demux->index_max_pos = pos;
@@ -194,44 +170,6 @@ gst_flv_demux_query_types (GstPad * pad)
   return query_types;
 }
 
-static void
-gst_flv_demux_check_seekability (GstFlvDemux * demux)
-{
-  GstQuery *query;
-  gint64 start = -1, stop = -1;
-
-  demux->upstream_seekable = FALSE;
-
-  query = gst_query_new_seeking (GST_FORMAT_BYTES);
-  if (!gst_pad_peer_query (demux->sinkpad, query)) {
-    GST_DEBUG_OBJECT (demux, "seeking query failed");
-    gst_query_unref (query);
-    return;
-  }
-
-  gst_query_parse_seeking (query, NULL, &demux->upstream_seekable,
-      &start, &stop);
-
-  gst_query_unref (query);
-
-  /* try harder to query upstream size if we didn't get it the first time */
-  if (demux->upstream_seekable && stop == -1) {
-    GstFormat fmt = GST_FORMAT_BYTES;
-
-    GST_DEBUG_OBJECT (demux, "doing duration query to fix up unset stop");
-    gst_pad_query_peer_duration (demux->sinkpad, &fmt, &stop);
-  }
-
-  /* if upstream doesn't know the size, it's likely that it's not seekable in
-   * practice even if it technically may be seekable */
-  if (demux->upstream_seekable && (start != 0 || stop <= start)) {
-    GST_DEBUG_OBJECT (demux, "seekable but unknown start/stop -> disable");
-    demux->upstream_seekable = FALSE;
-  }
-
-  GST_DEBUG_OBJECT (demux, "upstream seekable: %d", demux->upstream_seekable);
-}
-
 static void
 parse_flv_demux_parse_date_string (GDate * date, const gchar * s)
 {
@@ -327,12 +265,6 @@ gst_flv_demux_parse_metadata_item (GstFlvDemux * demux, GstByteReader * reader,
       } else if (!strcmp (tag_name, "AspectRatioY")) {
         demux->par_y = d;
         demux->got_par = TRUE;
-      } else if (!strcmp (tag_name, "width")) {
-        demux->w = d;
-      } else if (!strcmp (tag_name, "height")) {
-        demux->h = d;
-      } else if (!strcmp (tag_name, "framerate")) {
-        demux->framerate = d;
       } else {
         GST_INFO_OBJECT (demux, "Tag \'%s\' not handled", tag_name);
       }
@@ -571,7 +503,7 @@ gst_flv_demux_parse_tag_script (GstFlvDemux * demux, GstBuffer * buffer)
             return GST_FLOW_OK;
           }
 
-          /* The number of elements is just a hint, some files have
+          /* The number of elements is just a hint, some files have 
              nb_elements == 0 and actually contain items. */
           GST_DEBUG_OBJECT (demux, "there are approx. %d elements in the array",
               nb_elems);
@@ -627,20 +559,21 @@ gst_flv_demux_audio_negotiate (GstFlvDemux * demux, guint32 codec_tag,
     guint32 rate, guint32 channels, guint32 width)
 {
   GstCaps *caps = NULL;
-  gchar *codec_name = NULL;
+  const gchar *codec_name = NULL;
   gboolean ret = FALSE;
-  guint adjusted_rate = rate;
 
   switch (codec_tag) {
     case 1:
       caps = gst_caps_new_simple ("audio/x-adpcm", "layout", G_TYPE_STRING,
           "swf", NULL);
+      codec_name = "Shockwave ADPCM";
       break;
     case 2:
     case 14:
       caps = gst_caps_new_simple ("audio/mpeg",
           "mpegversion", G_TYPE_INT, 1, "layer", G_TYPE_INT, 3,
           "parsed", G_TYPE_BOOLEAN, TRUE, NULL);
+      codec_name = "MPEG 1 Audio, Layer 3 (MP3)";
       break;
     case 0:
     case 3:
@@ -651,45 +584,30 @@ gst_flv_demux_audio_negotiate (GstFlvDemux * demux, guint32 codec_tag,
           "endianness", G_TYPE_INT, G_LITTLE_ENDIAN,
           "signed", G_TYPE_BOOLEAN, (width == 8) ? FALSE : TRUE,
           "width", G_TYPE_INT, width, "depth", G_TYPE_INT, width, NULL);
+      codec_name = "Raw Audio";
       break;
     case 4:
     case 5:
     case 6:
       caps = gst_caps_new_simple ("audio/x-nellymoser", NULL);
+      codec_name = "Nellymoser ASAO";
       break;
     case 10:
-    {
-      /* use codec-data to extract and verify samplerate */
-      if (demux->audio_codec_data &&
-          GST_BUFFER_SIZE (demux->audio_codec_data) >= 2) {
-        gint freq_index;
-
-        freq_index =
-            ((GST_READ_UINT16_BE (GST_BUFFER_DATA (demux->audio_codec_data))));
-        freq_index = (freq_index & 0x0780) >> 7;
-        adjusted_rate =
-            gst_codec_utils_aac_get_sample_rate_from_index (freq_index);
-
-        if (adjusted_rate && (rate != adjusted_rate)) {
-          GST_LOG_OBJECT (demux, "Ajusting AAC sample rate %d -> %d", rate,
-              adjusted_rate);
-        } else {
-          adjusted_rate = rate;
-        }
-      }
       caps = gst_caps_new_simple ("audio/mpeg",
-          "mpegversion", G_TYPE_INT, 4, "framed", G_TYPE_BOOLEAN, TRUE,
-          "stream-format", G_TYPE_STRING, "raw", NULL);
+          "mpegversion", G_TYPE_INT, 4, "framed", G_TYPE_BOOLEAN, TRUE, NULL);
+      codec_name = "AAC";
       break;
-    }
     case 7:
       caps = gst_caps_new_simple ("audio/x-alaw", NULL);
+      codec_name = "A-Law";
       break;
     case 8:
       caps = gst_caps_new_simple ("audio/x-mulaw", NULL);
+      codec_name = "Mu-Law";
       break;
     case 11:
       caps = gst_caps_new_simple ("audio/x-speex", NULL);
+      codec_name = "Speex";
       break;
     default:
       GST_WARNING_OBJECT (demux, "unsupported audio codec tag %u", codec_tag);
@@ -700,8 +618,8 @@ gst_flv_demux_audio_negotiate (GstFlvDemux * demux, guint32 codec_tag,
     goto beach;
   }
 
-  gst_caps_set_simple (caps, "rate", G_TYPE_INT, adjusted_rate,
-      "channels", G_TYPE_INT, channels, NULL);
+  gst_caps_set_simple (caps,
+      "rate", G_TYPE_INT, rate, "channels", G_TYPE_INT, channels, NULL);
 
   if (demux->audio_codec_data) {
     gst_caps_set_simple (caps, "codec_data", GST_TYPE_BUFFER,
@@ -711,20 +629,17 @@ gst_flv_demux_audio_negotiate (GstFlvDemux * demux, guint32 codec_tag,
   ret = gst_pad_set_caps (demux->audio_pad, caps);
 
   if (G_LIKELY (ret)) {
-    /* Store the caps we got from tags */
+    /* Store the caps we have set */
     demux->audio_codec_tag = codec_tag;
     demux->rate = rate;
     demux->channels = channels;
     demux->width = width;
 
-    codec_name = gst_pb_utils_get_codec_description (caps);
-
     if (codec_name) {
       if (demux->taglist == NULL)
         demux->taglist = gst_tag_list_new ();
       gst_tag_list_add (demux->taglist, GST_TAG_MERGE_REPLACE,
           GST_TAG_AUDIO_CODEC, codec_name, NULL);
-      g_free (codec_name);
     }
 
     GST_DEBUG_OBJECT (demux->audio_pad, "successfully negotiated caps %"
@@ -740,45 +655,6 @@ beach:
   return ret;
 }
 
-static void
-gst_flv_demux_push_tags (GstFlvDemux * demux)
-{
-  if (demux->has_audio && !demux->audio_pad) {
-    GST_DEBUG_OBJECT (demux,
-        "Waiting for audio stream pad to come up before we can push tags");
-    return;
-  }
-  if (demux->has_video && !demux->video_pad) {
-    GST_DEBUG_OBJECT (demux,
-        "Waiting for video stream pad to come up before we can push tags");
-    return;
-  }
-  if (demux->taglist) {
-    GST_DEBUG_OBJECT (demux, "pushing tags out %" GST_PTR_FORMAT,
-        demux->taglist);
-    gst_element_found_tags (GST_ELEMENT (demux), demux->taglist);
-    demux->taglist = gst_tag_list_new ();
-    demux->push_tags = FALSE;
-  }
-}
-
-static void
-gst_flv_demux_update_resync (GstFlvDemux * demux, guint32 pts, gboolean discont,
-    guint32 * last, GstClockTime * offset)
-{
-  gint32 dpts = pts - *last;
-  if (!discont && ABS (dpts) >= RESYNC_THRESHOLD) {
-    /* Theoretically, we should use substract the duration of the last buffer,
-       but this demuxer sends no durations on buffers, not sure if it cannot
-       know, or just does not care to calculate. */
-    *offset -= dpts * GST_MSECOND;
-    GST_WARNING_OBJECT (demux,
-        "Large pts gap (%" G_GINT32_FORMAT " ms), assuming resync, offset now %"
-        GST_TIME_FORMAT "", dpts, GST_TIME_ARGS (*offset));
-  }
-  *last = pts;
-}
-
 static GstFlowReturn
 gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
 {
@@ -800,6 +676,9 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
   g_return_val_if_fail (GST_BUFFER_SIZE (buffer) == demux->tag_size,
       GST_FLOW_ERROR);
 
+  GST_LOG_OBJECT (demux, "pts bytes %02X %02X %02X %02X", data[0], data[1],
+      data[2], data[3]);
+
   /* Grab information about audio tag */
   pts = GST_READ_UINT24_BE (data);
   /* read the pts extension to 32 bits integer */
@@ -807,9 +686,6 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
   /* Combine them */
   pts |= pts_ext << 24;
 
-  GST_LOG_OBJECT (demux, "pts bytes %02X %02X %02X %02X (%d)", data[0], data[1],
-      data[2], data[3], pts);
-
   /* Error out on tags with too small headers */
   if (GST_BUFFER_SIZE (buffer) < 11) {
     GST_ERROR_OBJECT (demux, "Too small tag size (%d)",
@@ -900,13 +776,12 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
         gst_object_ref (demux->audio_pad));
 
     /* We only emit no more pads when we have audio and video. Indeed we can
-     * not trust the FLV header to tell us if there will be only audio or
+     * not trust the FLV header to tell us if there will be only audio or 
      * only video and we would just break discovery of some files */
     if (demux->audio_pad && demux->video_pad) {
       GST_DEBUG_OBJECT (demux, "emitting no more pads");
       gst_element_no_more_pads (GST_ELEMENT (demux));
       demux->no_more_pads = TRUE;
-      demux->push_tags = TRUE;
     }
   }
 
@@ -924,8 +799,18 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
   }
 
   /* Push taglist if present */
-  if (G_UNLIKELY (demux->push_tags))
-    gst_flv_demux_push_tags (demux);
+  if ((demux->has_audio && !demux->audio_pad) &&
+      (demux->has_video && !demux->video_pad)) {
+    GST_DEBUG_OBJECT (demux, "we are still waiting for a stream to come up "
+        "before we can push tags");
+  } else {
+    if (demux->taglist && demux->push_tags) {
+      GST_DEBUG_OBJECT (demux, "pushing tags out");
+      gst_element_found_tags (GST_ELEMENT (demux), demux->taglist);
+      demux->taglist = gst_tag_list_new ();
+      demux->push_tags = FALSE;
+    }
+  }
 
   /* Check if we have anything to push */
   if (demux->tag_data_size <= codec_data) {
@@ -944,7 +829,7 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
     switch (aac_packet_type) {
       case 0:
       {
-        /* AudioSpecificConfig data */
+        /* AudioSpecificConfic data */
         GST_LOG_OBJECT (demux, "got an AAC codec data packet");
         if (demux->audio_codec_data) {
           gst_buffer_unref (demux->audio_codec_data);
@@ -965,12 +850,8 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
     }
   }
 
-  /* detect (and deem to be resyncs)  large pts gaps */
-  gst_flv_demux_update_resync (demux, pts, demux->audio_need_discont,
-      &demux->last_audio_pts, &demux->audio_time_offset);
-
   /* Fill buffer with data */
-  GST_BUFFER_TIMESTAMP (outbuf) = pts * GST_MSECOND + demux->audio_time_offset;
+  GST_BUFFER_TIMESTAMP (outbuf) = pts * GST_MSECOND;
   GST_BUFFER_DURATION (outbuf) = GST_CLOCK_TIME_NONE;
   GST_BUFFER_OFFSET (outbuf) = demux->audio_offset++;
   GST_BUFFER_OFFSET_END (outbuf) = demux->audio_offset;
@@ -1039,7 +920,6 @@ gst_flv_demux_parse_tag_audio (GstFlvDemux * demux, GstBuffer * buffer)
         " after 6 seconds of audio");
     gst_element_no_more_pads (GST_ELEMENT_CAST (demux));
     demux->no_more_pads = TRUE;
-    demux->push_tags = TRUE;
   }
 
   /* Push downstream */
@@ -1075,26 +955,29 @@ gst_flv_demux_video_negotiate (GstFlvDemux * demux, guint32 codec_tag)
 {
   gboolean ret = FALSE;
   GstCaps *caps = NULL;
-  gchar *codec_name = NULL;
+  const gchar *codec_name = NULL;
 
   /* Generate caps for that pad */
   switch (codec_tag) {
     case 2:
       caps = gst_caps_new_simple ("video/x-flash-video", NULL);
+      codec_name = "Sorenson Video";
       break;
     case 3:
       caps = gst_caps_new_simple ("video/x-flash-screen", NULL);
+      codec_name = "Flash Screen Video";
       break;
     case 4:
       caps = gst_caps_new_simple ("video/x-vp6-flash", NULL);
+      codec_name = "On2 VP6 Video";
       break;
     case 5:
       caps = gst_caps_new_simple ("video/x-vp6-alpha", NULL);
+      codec_name = "On2 VP6 Video with alpha channel";
       break;
     case 7:
-      caps =
-          gst_caps_new_simple ("video/x-h264", "stream-format", G_TYPE_STRING,
-          "avc", NULL);
+      caps = gst_caps_new_simple ("video/x-h264", NULL);
+      codec_name = "H.264/AVC Video";
       break;
     default:
       GST_WARNING_OBJECT (demux, "unsupported video codec tag %u", codec_tag);
@@ -1108,25 +991,6 @@ gst_flv_demux_video_negotiate (GstFlvDemux * demux, guint32 codec_tag)
   gst_caps_set_simple (caps, "pixel-aspect-ratio", GST_TYPE_FRACTION,
       demux->par_x, demux->par_y, NULL);
 
-  if (G_LIKELY (demux->w)) {
-    gst_caps_set_simple (caps, "width", G_TYPE_INT, demux->w, NULL);
-  }
-
-  if (G_LIKELY (demux->h)) {
-    gst_caps_set_simple (caps, "height", G_TYPE_INT, demux->h, NULL);
-  }
-
-  if (G_LIKELY (demux->framerate)) {
-    gint num = 0, den = 0;
-
-    gst_util_double_to_fraction (demux->framerate, &num, &den);
-    GST_DEBUG_OBJECT (demux->video_pad,
-        "fps to be used on caps %f (as a fraction = %d/%d)", demux->framerate,
-        num, den);
-
-    gst_caps_set_simple (caps, "framerate", GST_TYPE_FRACTION, num, den, NULL);
-  }
-
   if (demux->video_codec_data) {
     gst_caps_set_simple (caps, "codec_data", GST_TYPE_BUFFER,
         demux->video_codec_data, NULL);
@@ -1138,14 +1002,11 @@ gst_flv_demux_video_negotiate (GstFlvDemux * demux, guint32 codec_tag)
     /* Store the caps we have set */
     demux->video_codec_tag = codec_tag;
 
-    codec_name = gst_pb_utils_get_codec_description (caps);
-
     if (codec_name) {
       if (demux->taglist == NULL)
         demux->taglist = gst_tag_list_new ();
       gst_tag_list_add (demux->taglist, GST_TAG_MERGE_REPLACE,
           GST_TAG_VIDEO_CODEC, codec_name, NULL);
-      g_free (codec_name);
     }
 
     GST_DEBUG_OBJECT (demux->video_pad, "successfully negotiated caps %"
@@ -1177,6 +1038,9 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
   GST_LOG_OBJECT (demux, "parsing a video tag");
 
 
+  GST_LOG_OBJECT (demux, "pts bytes %02X %02X %02X %02X", data[0], data[1],
+      data[2], data[3]);
+
   if (demux->no_more_pads && !demux->video_pad) {
     GST_WARNING_OBJECT (demux,
         "Signaled no-more-pads already but had no audio pad -- ignoring");
@@ -1190,9 +1054,6 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
   /* Combine them */
   pts |= pts_ext << 24;
 
-  GST_LOG_OBJECT (demux, "pts bytes %02X %02X %02X %02X (%d)", data[0], data[1],
-      data[2], data[3], pts);
-
   if (GST_BUFFER_SIZE (buffer) < 12) {
     GST_ERROR_OBJECT (demux, "Too small tag size");
     return GST_FLOW_ERROR;
@@ -1210,18 +1071,7 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
   if (codec_tag == 4 || codec_tag == 5) {
     codec_data = 2;
   } else if (codec_tag == 7) {
-    gint32 cts;
-
     codec_data = 5;
-
-    cts = GST_READ_UINT24_BE (data + 9);
-    cts = (cts + 0xff800000) ^ 0xff800000;
-
-    GST_LOG_OBJECT (demux, "got cts %d", cts);
-
-    /* avoid negative overflow */
-    if (cts >= 0 || pts >= -cts)
-      pts += cts;
   }
 
   GST_LOG_OBJECT (demux, "video tag with codec tag %u, keyframe (%d) "
@@ -1245,7 +1095,7 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
       goto beach;
     }
 
-    /* When we ve set pixel-aspect-ratio we use that boolean to detect a
+    /* When we ve set pixel-aspect-ratio we use that boolean to detect a 
      * metadata tag that would come later and trigger a caps change */
     demux->got_par = FALSE;
 
@@ -1270,13 +1120,12 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
         gst_object_ref (demux->video_pad));
 
     /* We only emit no more pads when we have audio and video. Indeed we can
-     * not trust the FLV header to tell us if there will be only audio or
+     * not trust the FLV header to tell us if there will be only audio or 
      * only video and we would just break discovery of some files */
     if (demux->audio_pad && demux->video_pad) {
       GST_DEBUG_OBJECT (demux, "emitting no more pads");
       gst_element_no_more_pads (GST_ELEMENT (demux));
       demux->no_more_pads = TRUE;
-      demux->push_tags = TRUE;
     }
   }
 
@@ -1290,14 +1139,24 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
       goto beach;
     }
 
-    /* When we ve set pixel-aspect-ratio we use that boolean to detect a
+    /* When we ve set pixel-aspect-ratio we use that boolean to detect a 
      * metadata tag that would come later and trigger a caps change */
     demux->got_par = FALSE;
   }
 
   /* Push taglist if present */
-  if (G_UNLIKELY (demux->push_tags))
-    gst_flv_demux_push_tags (demux);
+  if ((demux->has_audio && !demux->audio_pad) &&
+      (demux->has_video && !demux->video_pad)) {
+    GST_DEBUG_OBJECT (demux, "we are still waiting for a stream to come up "
+        "before we can push tags");
+  } else {
+    if (demux->taglist && demux->push_tags) {
+      GST_DEBUG_OBJECT (demux, "pushing tags out");
+      gst_element_found_tags (GST_ELEMENT (demux), demux->taglist);
+      demux->taglist = gst_tag_list_new ();
+      demux->push_tags = FALSE;
+    }
+  }
 
   /* Check if we have anything to push */
   if (demux->tag_data_size <= codec_data) {
@@ -1337,12 +1196,8 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
     }
   }
 
-  /* detect (and deem to be resyncs)  large pts gaps */
-  gst_flv_demux_update_resync (demux, pts, demux->video_need_discont,
-      &demux->last_video_pts, &demux->video_time_offset);
-
   /* Fill buffer with data */
-  GST_BUFFER_TIMESTAMP (outbuf) = pts * GST_MSECOND + demux->video_time_offset;
+  GST_BUFFER_TIMESTAMP (outbuf) = pts * GST_MSECOND;
   GST_BUFFER_DURATION (outbuf) = GST_CLOCK_TIME_NONE;
   GST_BUFFER_OFFSET (outbuf) = demux->video_offset++;
   GST_BUFFER_OFFSET_END (outbuf) = demux->video_offset;
@@ -1414,7 +1269,6 @@ gst_flv_demux_parse_tag_video (GstFlvDemux * demux, GstBuffer * buffer)
         " after 6 seconds of video");
     gst_element_no_more_pads (GST_ELEMENT_CAST (demux));
     demux->no_more_pads = TRUE;
-    demux->push_tags = TRUE;
   }
 
   /* Push downstream */
@@ -1592,9 +1446,6 @@ gst_flv_demux_parse_header (GstFlvDemux * demux, GstBuffer * buffer)
     }
   }
 
-  /* do a one-time seekability check */
-  gst_flv_demux_check_seekability (demux);
-
   /* We don't care about the rest */
   demux->need_header = FALSE;
 
@@ -1648,22 +1499,18 @@ gst_flv_demux_cleanup (GstFlvDemux * demux)
   demux->got_par = FALSE;
 
   demux->indexed = FALSE;
-  demux->upstream_seekable = FALSE;
   demux->file_size = 0;
 
   demux->index_max_pos = 0;
   demux->index_max_time = 0;
 
   demux->audio_start = demux->video_start = GST_CLOCK_TIME_NONE;
-  demux->last_audio_pts = demux->last_video_pts = 0;
-  demux->audio_time_offset = demux->video_time_offset = 0;
 
   demux->no_more_pads = FALSE;
 
   gst_segment_init (&demux->segment, GST_FORMAT_TIME);
 
   demux->w = demux->h = 0;
-  demux->framerate = 0.0;
   demux->par_x = demux->par_y = 1;
   demux->video_offset = 0;
   demux->audio_offset = 0;
@@ -1761,11 +1608,6 @@ gst_flv_demux_chain (GstPad * pad, GstBuffer * buffer)
     demux->offset = GST_BUFFER_OFFSET (buffer);
   }
 
-  if (GST_BUFFER_FLAG_IS_SET (buffer, GST_BUFFER_FLAG_DISCONT)) {
-    GST_DEBUG_OBJECT (demux, "Discontinuity");
-    gst_adapter_clear (demux->adapter);
-  }
-
   gst_adapter_push (demux->adapter, buffer);
 
   if (demux->seeking) {
@@ -2377,49 +2219,51 @@ pause:
     GST_LOG_OBJECT (demux, "pausing task, reason %s", reason);
     gst_pad_pause_task (pad);
 
-    if (ret == GST_FLOW_UNEXPECTED) {
-      /* perform EOS logic */
-      if (!demux->no_more_pads) {
-        gst_element_no_more_pads (GST_ELEMENT_CAST (demux));
-        demux->no_more_pads = TRUE;
-      }
-
-      if (demux->segment.flags & GST_SEEK_FLAG_SEGMENT) {
-        gint64 stop;
-
-        /* for segment playback we need to post when (in stream time)
-         * we stopped, this is either stop (when set) or the duration. */
-        if ((stop = demux->segment.stop) == -1)
-          stop = demux->segment.duration;
-
-        if (demux->segment.rate >= 0) {
-          GST_LOG_OBJECT (demux, "Sending segment done, at end of segment");
-          gst_element_post_message (GST_ELEMENT_CAST (demux),
-              gst_message_new_segment_done (GST_OBJECT_CAST (demux),
-                  GST_FORMAT_TIME, stop));
-        } else {                /* Reverse playback */
-          GST_LOG_OBJECT (demux, "Sending segment done, at beginning of "
-              "segment");
-          gst_element_post_message (GST_ELEMENT_CAST (demux),
-              gst_message_new_segment_done (GST_OBJECT_CAST (demux),
-                  GST_FORMAT_TIME, demux->segment.start));
-        }
-      } else {
-        /* normal playback, send EOS to all linked pads */
+    if (GST_FLOW_IS_FATAL (ret) || ret == GST_FLOW_NOT_LINKED) {
+      if (ret == GST_FLOW_UNEXPECTED) {
+        /* perform EOS logic */
         if (!demux->no_more_pads) {
-          gst_element_no_more_pads (GST_ELEMENT (demux));
+          gst_element_no_more_pads (GST_ELEMENT_CAST (demux));
           demux->no_more_pads = TRUE;
         }
 
-        GST_LOG_OBJECT (demux, "Sending EOS, at end of stream");
-        if (!gst_flv_demux_push_src_event (demux, gst_event_new_eos ()))
-          GST_WARNING_OBJECT (demux, "failed pushing EOS on streams");
+        if (demux->segment.flags & GST_SEEK_FLAG_SEGMENT) {
+          gint64 stop;
+
+          /* for segment playback we need to post when (in stream time)
+           * we stopped, this is either stop (when set) or the duration. */
+          if ((stop = demux->segment.stop) == -1)
+            stop = demux->segment.duration;
+
+          if (demux->segment.rate >= 0) {
+            GST_LOG_OBJECT (demux, "Sending segment done, at end of segment");
+            gst_element_post_message (GST_ELEMENT_CAST (demux),
+                gst_message_new_segment_done (GST_OBJECT_CAST (demux),
+                    GST_FORMAT_TIME, stop));
+          } else {              /* Reverse playback */
+            GST_LOG_OBJECT (demux, "Sending segment done, at beginning of "
+                "segment");
+            gst_element_post_message (GST_ELEMENT_CAST (demux),
+                gst_message_new_segment_done (GST_OBJECT_CAST (demux),
+                    GST_FORMAT_TIME, demux->segment.start));
+          }
+        } else {
+          /* normal playback, send EOS to all linked pads */
+          if (!demux->no_more_pads) {
+            gst_element_no_more_pads (GST_ELEMENT (demux));
+            demux->no_more_pads = TRUE;
+          }
+
+          GST_LOG_OBJECT (demux, "Sending EOS, at end of stream");
+          if (!gst_flv_demux_push_src_event (demux, gst_event_new_eos ()))
+            GST_WARNING_OBJECT (demux, "failed pushing EOS on streams");
+        }
+      } else {
+        GST_ELEMENT_ERROR (demux, STREAM, FAILED,
+            ("Internal data stream error."),
+            ("stream stopped, reason %s", reason));
+        gst_flv_demux_push_src_event (demux, gst_event_new_eos ());
       }
-    } else if (ret == GST_FLOW_NOT_LINKED || ret < GST_FLOW_UNEXPECTED) {
-      GST_ELEMENT_ERROR (demux, STREAM, FAILED,
-          ("Internal data stream error."),
-          ("stream stopped, reason %s", reason));
-      gst_flv_demux_push_src_event (demux, gst_event_new_eos ());
     }
     gst_object_unref (demux);
     return;
@@ -2476,7 +2320,7 @@ flv_demux_handle_seek_push (GstFlvDemux * demux, GstEvent * event)
   GstSeekType start_type, stop_type;
   gint64 start, stop;
   gdouble rate;
-  gboolean update, flush, ret;
+  gboolean update, flush, keyframe, ret;
   GstSegment seeksegment;
 
   gst_event_parse_seek (event, &rate, &format, &flags,
@@ -2485,8 +2329,9 @@ flv_demux_handle_seek_push (GstFlvDemux * demux, GstEvent * event)
   if (format != GST_FORMAT_TIME)
     goto wrong_format;
 
-  flush = ! !(flags & GST_SEEK_FLAG_FLUSH);
+  flush = !!(flags & GST_SEEK_FLAG_FLUSH);
   /* FIXME : the keyframe flag is never used ! */
+  keyframe = !!(flags & GST_SEEK_FLAG_KEY_UNIT);
 
   /* Work on a copy until we are sure the seek succeeded. */
   memcpy (&seeksegment, &demux->segment, sizeof (GstSegment));
@@ -2546,31 +2391,13 @@ flv_demux_handle_seek_push (GstFlvDemux * demux, GstEvent * event)
 wrong_format:
   {
     GST_WARNING_OBJECT (demux, "we only support seeking in TIME format");
-    gst_event_unref (event);
-    return FALSE;
+    return gst_pad_push_event (demux->sinkpad, event);
   }
 }
 
 static gboolean
 gst_flv_demux_handle_seek_push (GstFlvDemux * demux, GstEvent * event)
 {
-  GstFormat format;
-
-  gst_event_parse_seek (event, NULL, &format, NULL, NULL, NULL, NULL, NULL);
-
-  if (format != GST_FORMAT_TIME) {
-    GST_WARNING_OBJECT (demux, "we only support seeking in TIME format");
-    gst_event_unref (event);
-    return FALSE;
-  }
-
-  /* First try upstream */
-  if (gst_pad_push_event (demux->sinkpad, gst_event_ref (event))) {
-    GST_DEBUG_OBJECT (demux, "Upstream successfully seeked");
-    gst_event_unref (event);
-    return TRUE;
-  }
-
   if (!demux->indexed) {
     guint64 seek_offset = 0;
     gboolean building_index;
@@ -2635,7 +2462,7 @@ gst_flv_demux_handle_seek_pull (GstFlvDemux * demux, GstEvent * event,
   GstSeekType start_type, stop_type;
   gint64 start, stop;
   gdouble rate;
-  gboolean update, flush, ret = FALSE;
+  gboolean update, flush, keyframe, ret = FALSE;
   GstSegment seeksegment;
 
   gst_event_parse_seek (event, &rate, &format, &flags,
@@ -2650,8 +2477,9 @@ gst_flv_demux_handle_seek_pull (GstFlvDemux * demux, GstEvent * event,
     demux->seeking = seeking;
   GST_OBJECT_UNLOCK (demux);
 
-  flush = ! !(flags & GST_SEEK_FLAG_FLUSH);
+  flush = !!(flags & GST_SEEK_FLAG_FLUSH);
   /* FIXME : the keyframe flag is never used */
+  keyframe = !!(flags & GST_SEEK_FLAG_KEY_UNIT);
 
   if (flush) {
     /* Flush start up and downstream to make sure data flow and loops are
@@ -2702,8 +2530,6 @@ gst_flv_demux_handle_seek_pull (GstFlvDemux * demux, GstEvent * event,
       demux->seek_event = gst_event_ref (event);
       demux->seek_time = seeksegment.last_stop;
       demux->state = FLV_STATE_SEEK;
-      /* do not know about succes yet, but we did care and handled it */
-      ret = TRUE;
       goto exit;
     }
     /* now index should be as reliable as it can be for current purpose */
@@ -3010,7 +2836,7 @@ gst_flv_demux_query (GstPad * pad, GstQuery * query)
       GST_DEBUG_OBJECT (pad, "position query, replying %" GST_TIME_FORMAT,
           GST_TIME_ARGS (demux->segment.last_stop));
 
-      gst_query_set_position (query, GST_FORMAT_TIME, demux->segment.last_stop);
+      gst_query_set_duration (query, GST_FORMAT_TIME, demux->segment.last_stop);
 
       break;
     }
@@ -3019,17 +2845,6 @@ gst_flv_demux_query (GstPad * pad, GstQuery * query)
       GstFormat fmt;
 
       gst_query_parse_seeking (query, &fmt, NULL, NULL, NULL);
-
-      /* First ask upstream */
-      if (fmt == GST_FORMAT_TIME && gst_pad_peer_query (demux->sinkpad, query)) {
-        gboolean seekable;
-
-        gst_query_parse_seeking (query, NULL, &seekable, NULL, NULL);
-        if (seekable) {
-          res = TRUE;
-          break;
-        }
-      }
       res = TRUE;
       if (fmt != GST_FORMAT_TIME || !demux->index) {
         gst_query_set_seeking (query, fmt, FALSE, -1, -1);
@@ -3134,16 +2949,12 @@ gst_flv_demux_set_index (GstElement * element, GstIndex * index)
     gst_object_unref (demux->index);
   if (index) {
     demux->index = gst_object_ref (index);
+    gst_index_get_writer_id (index, GST_OBJECT (element), &demux->index_id);
     demux->own_index = FALSE;
   } else
     demux->index = NULL;
 
   GST_OBJECT_UNLOCK (demux);
-  /* object lock might be taken again */
-  if (index)
-    gst_index_get_writer_id (index, GST_OBJECT (element), &demux->index_id);
-  GST_DEBUG_OBJECT (demux, "Set index %" GST_PTR_FORMAT, demux->index);
-
 }
 
 static GstIndex *
@@ -3232,12 +3043,12 @@ gst_flv_demux_base_init (gpointer g_class)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
 
-  gst_element_class_add_static_pad_template (element_class,
-      &flv_sink_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &audio_src_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &video_src_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&flv_sink_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&audio_src_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&video_src_template));
   gst_element_class_set_details_simple (element_class, "FLV Demuxer",
       "Codec/Demuxer",
       "Demux FLV feeds into digital streams",
@@ -3250,7 +3061,7 @@ gst_flv_demux_class_init (GstFlvDemuxClass * klass)
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (klass);
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  gobject_class->dispose = gst_flv_demux_dispose;
+  gobject_class->dispose = GST_DEBUG_FUNCPTR (gst_flv_demux_dispose);
 
   gstelement_class->change_state =
       GST_DEBUG_FUNCPTR (gst_flv_demux_change_state);
