@@ -26,13 +26,6 @@
 #include <gst/rtp/gstrtpbuffer.h>
 #include "gstrtpilbcdepay.h"
 
-/* elementfactory information */
-static const GstElementDetails gst_rtp_ilbc_depay_details =
-GST_ELEMENT_DETAILS ("RTP iLBC depayloader",
-    "Codec/Depayloader/Network",
-    "Extracts iLBC audio from RTP packets (RFC 3952)",
-    "Philippe Kalaf <philippe.kalaf@collabora.co.uk>");
-
 /* RtpiLBCDepay signals and args */
 enum
 {
@@ -107,7 +100,10 @@ gst_rtp_ilbc_depay_base_init (gpointer klass)
       gst_static_pad_template_get (&gst_rtp_ilbc_depay_src_template));
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&gst_rtp_ilbc_depay_sink_template));
-  gst_element_class_set_details (element_class, &gst_rtp_ilbc_depay_details);
+  gst_element_class_set_details_simple (element_class, "RTP iLBC depayloader",
+      "Codec/Depayloader/Network",
+      "Extracts iLBC audio from RTP packets (RFC 3952)",
+      "Philippe Kalaf <philippe.kalaf@collabora.co.uk>");
 }
 
 static void
