@@ -27,13 +27,6 @@
 #include <gst/rtp/gstrtpbuffer.h>
 #include "gstrtppcmudepay.h"
 
-/* elementfactory information */
-static const GstElementDetails gst_rtp_pcmudepay_details =
-GST_ELEMENT_DETAILS ("RTP PCMU depayloader",
-    "Codec/Depayloader/Network",
-    "Extracts PCMU audio from RTP packets",
-    "Edgard Lima <edgard.lima@indt.org.br>, Zeeshan Ali <zeenix@gmail.com>");
-
 /* RtpPcmuDepay signals and args */
 enum
 {
@@ -84,7 +77,10 @@ gst_rtp_pcmu_depay_base_init (gpointer klass)
       gst_static_pad_template_get (&gst_rtp_pcmu_depay_src_template));
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&gst_rtp_pcmu_depay_sink_template));
-  gst_element_class_set_details (element_class, &gst_rtp_pcmudepay_details);
+  gst_element_class_set_details_simple (element_class, "RTP PCMU depayloader",
+      "Codec/Depayloader/Network",
+      "Extracts PCMU audio from RTP packets",
+      "Edgard Lima <edgard.lima@indt.org.br>, Zeeshan Ali <zeenix@gmail.com>");
 }
 
 static void
@@ -94,8 +90,6 @@ gst_rtp_pcmu_depay_class_init (GstRtpPcmuDepayClass * klass)
 
   gstbasertpdepayload_class = (GstBaseRTPDepayloadClass *) klass;
 
-  parent_class = g_type_class_peek_parent (klass);
-
   gstbasertpdepayload_class->process = gst_rtp_pcmu_depay_process;
   gstbasertpdepayload_class->set_caps = gst_rtp_pcmu_depay_setcaps;
 }
