@@ -30,13 +30,6 @@
 GST_DEBUG_CATEGORY_STATIC (rtptheoradepay_debug);
 #define GST_CAT_DEFAULT (rtptheoradepay_debug)
 
-/* elementfactory information */
-static const GstElementDetails gst_rtp_theora_depay_details =
-GST_ELEMENT_DETAILS ("RTP Theora depayloader",
-    "Codec/Depayloader/Network",
-    "Extracts Theora video from RTP packets (draft-01 of RFC XXXX)",
-    "Wim Taymans <wim.taymans@gmail.com>");
-
 static GstStaticPadTemplate gst_rtp_theora_depay_sink_template =
 GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
@@ -90,7 +83,10 @@ gst_rtp_theora_depay_base_init (gpointer klass)
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&gst_rtp_theora_depay_src_template));
 
-  gst_element_class_set_details (element_class, &gst_rtp_theora_depay_details);
+  gst_element_class_set_details_simple (element_class, "RTP Theora depayloader",
+      "Codec/Depayloader/Network",
+      "Extracts Theora video from RTP packets (draft-01 of RFC XXXX)",
+      "Wim Taymans <wim.taymans@gmail.com>");
 }
 
 static void
