@@ -141,19 +141,6 @@ typedef struct {
   RTPSessionReconsider  reconsider;
 } RTPSessionCallbacks;
 
-/**
- * RTPConflictingAddress:
- * @address: #GstNetAddress which conflicted
- * @last_conflict_time: time when the last conflict was seen
- *
- * This structure is used to account for addresses that have conflicted to find
- * loops.
- */
-typedef struct {
-  GstNetAddress address;
-  GstClockTime time;
-} RTPConflictingAddress;
-
 /**
  * RTPSession:
  * @lock: lock to protect the session
@@ -165,7 +152,6 @@ typedef struct {
  * @callbacks: callbacks
  * @user_data: user data passed in callbacks
  * @stats: session statistics
- * @conflicting_addresses: GList of conflicting addresses
  *
  * The RTP session manager object
  */
@@ -204,8 +190,8 @@ struct _RTPSession {
 
   RTPSessionStats stats;
 
-  GList         *conflicting_addresses;
   gboolean      change_ssrc;
+  gboolean      favor_new;
 };
 
 /**
@@ -286,13 +272,13 @@ RTPSource*      rtp_session_create_source          (RTPSession *sess);
 /* processing packets from receivers */
 GstFlowReturn   rtp_session_process_rtp            (RTPSession *sess, GstBuffer *buffer,
                                                     GstClockTime current_time,
-						    GstClockTime running_time, guint64 ntpnstime);
+						    GstClockTime running_time);
 GstFlowReturn   rtp_session_process_rtcp           (RTPSession *sess, GstBuffer *buffer,
                                                     GstClockTime current_time);
 
 /* processing packets for sending */
 GstFlowReturn   rtp_session_send_rtp               (RTPSession *sess, gpointer data, gboolean is_list,
-                                                    GstClockTime current_time, guint64 ntpnstime);
+                                                    GstClockTime current_time, GstClockTime running_time);
 
 /* stopping the session */
 GstFlowReturn   rtp_session_schedule_bye           (RTPSession *sess, const gchar *reason,
@@ -301,6 +287,6 @@ GstFlowReturn   rtp_session_schedule_bye           (RTPSession *sess, const gcha
 /* get interval for next RTCP interval */
 GstClockTime    rtp_session_next_timeout           (RTPSession *sess, GstClockTime current_time);
 GstFlowReturn   rtp_session_on_timeout             (RTPSession *sess, GstClockTime current_time,
-                                                    guint64 ntpnstime);
+                                                    guint64 ntpnstime, GstClockTime running_time);
 
 #endif /* __RTP_SESSION_H__ */
