@@ -106,6 +106,7 @@ struct _GstRTSPStream {
   /* our udp sources */
   GstElement   *udpsrc[2];
   GstPad       *blockedpad;
+  gboolean      is_ipv6;
 
   /* our udp sinks back to the server */
   GstElement   *udpsink[2];
@@ -193,6 +194,10 @@ struct _GstRTSPSrc {
   guint             proxy_port;
   gchar            *proxy_user;
   gchar            *proxy_passwd;
+  guint             rtp_blocksize;
+  gchar            *user_id;
+  gchar            *user_pw;
+  gint              buffer_mode;
 
   /* state */
   GstRTSPState       state;
