@@ -1,5 +1,6 @@
 /* GStreamer
  * Copyright (C) <2007> Wim Taymans <wim.taymans@gmail.com>
+ * Copyright (C) <2009> Jarkko Palviainen <jarkko.palviainen@sesca.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -18,7 +19,7 @@
  */
 
 /**
- * SECTION:element-multiupdsink
+ * SECTION:element-multiudpsink
  * @see_also: udpsink, multifdsink
  *
  * multiudpsink is a network sink that sends UDP packets to multiple
@@ -48,13 +49,6 @@ static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS_ANY);
 
-/* elementfactory information */
-static const GstElementDetails gst_multiudpsink_details =
-GST_ELEMENT_DETAILS ("UDP packet sender",
-    "Sink/Network",
-    "Send data over the network via UDP",
-    "Wim Taymans <wim.taymans@gmail.com>");
-
 /* MultiUDPSink signals and args */
 enum
 {
@@ -76,11 +70,13 @@ enum
 #define DEFAULT_CLOSEFD            TRUE
 #define DEFAULT_SOCK               -1
 #define DEFAULT_CLIENTS            NULL
+#define DEFAULT_FAMILY             0
 /* FIXME, this should be disabled by default, we don't need to join a multicast
  * group for sending, if this socket is also used for receiving, it should
  * be configured in the element that does the receive. */
 #define DEFAULT_AUTO_MULTICAST     TRUE
 #define DEFAULT_TTL                64
+#define DEFAULT_TTL_MC             1
 #define DEFAULT_LOOP               TRUE
 #define DEFAULT_QOS_DSCP           -1
 
@@ -95,6 +91,7 @@ enum
   PROP_CLIENTS,
   PROP_AUTO_MULTICAST,
   PROP_TTL,
+  PROP_TTL_MC,
   PROP_LOOP,
   PROP_QOS_DSCP,
   PROP_LAST
@@ -174,7 +171,10 @@ gst_multiudpsink_base_init (gpointer g_class)
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&sink_template));
 
-  gst_element_class_set_details (element_class, &gst_multiudpsink_details);
+  gst_element_class_set_details_simple (element_class, "UDP packet sender",
+      "Sink/Network",
+      "Send data over the network via UDP",
+      "Wim Taymans <wim.taymans@gmail.com>");
 }
 
 static void
@@ -307,9 +307,13 @@ gst_multiudpsink_class_init (GstMultiUDPSinkClass * klass)
           "Automatically join/leave the multicast groups, FALSE means user"
           " has to do it himself", DEFAULT_AUTO_MULTICAST, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_TTL,
-      g_param_spec_int ("ttl", "Multicast TTL",
-          "Used for setting the multicast TTL parameter",
+      g_param_spec_int ("ttl", "Unicast TTL",
+          "Used for setting the unicast TTL parameter",
           0, 255, DEFAULT_TTL, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_TTL_MC,
+      g_param_spec_int ("ttl-mc", "Multicast TTL",
+          "Used for setting the multicast TTL parameter",
+          0, 255, DEFAULT_TTL_MC, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_LOOP,
       g_param_spec_boolean ("loop", "Multicast Loopback",
           "Used for setting the multicast loop parameter. TRUE = enable,"
@@ -346,8 +350,10 @@ gst_multiudpsink_init (GstMultiUDPSink * sink)
   sink->externalfd = (sink->sockfd != -1);
   sink->auto_multicast = DEFAULT_AUTO_MULTICAST;
   sink->ttl = DEFAULT_TTL;
+  sink->ttl_mc = DEFAULT_TTL_MC;
   sink->loop = DEFAULT_LOOP;
   sink->qos_dscp = DEFAULT_QOS_DSCP;
+  sink->ss_family = DEFAULT_FAMILY;
 }
 
 static void
@@ -370,6 +376,51 @@ gst_multiudpsink_finalize (GObject * object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+static gboolean
+socket_error_is_ignorable (void)
+{
+#ifdef G_OS_WIN32
+  /* Windows doesn't seem to have an EAGAIN for sockets */
+  return WSAGetLastError () == WSAEINTR;
+#else
+  return errno == EINTR || errno == EAGAIN;
+#endif
+}
+
+static int
+socket_last_error_code (void)
+{
+#ifdef G_OS_WIN32
+  return WSAGetLastError ();
+#else
+  return errno;
+#endif
+}
+
+static gchar *
+socket_last_error_message (void)
+{
+#ifdef G_OS_WIN32
+  int errorcode = WSAGetLastError ();
+  wchar_t buf[1024];
+  DWORD result =
+      FormatMessage (FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
+      NULL, errorcode, 0, (LPSTR) buf, sizeof (buf) / sizeof (wchar_t), NULL);
+  if (FAILED (result)) {
+    return g_strdup ("failed to get error message from system");
+  } else {
+    gchar *res =
+        g_convert ((gchar *) buf, -1, "UTF-16", "UTF-8", NULL, NULL, NULL);
+    /* g_convert() internally calls windows functions which reset the
+       windows error code, so fix it up again like this */
+    WSASetLastError (errorcode);
+    return res;
+  }
+#else
+  return g_strdup (g_strerror (errno));
+#endif
+}
+
 static GstFlowReturn
 gst_multiudpsink_render (GstBaseSink * bsink, GstBuffer * buffer)
 {
@@ -412,9 +463,11 @@ gst_multiudpsink_render (GstBaseSink * bsink, GstBuffer * buffer)
       if (ret < 0) {
         /* some error, just warn, it's likely recoverable and we don't want to
          * break streaming. We break so that we stop retrying for this client. */
-        if (errno != EINTR && errno != EAGAIN) {
+        if (!socket_error_is_ignorable ()) {
+          gchar *errormessage = socket_last_error_message ();
           GST_WARNING_OBJECT (sink, "client %p gave error %d (%s)", client,
-              errno, g_strerror (errno));
+              socket_last_error_code (), errormessage);
+          g_free (errormessage);
           break;
         }
       } else {
@@ -493,7 +546,7 @@ gst_multiudpsink_render_list (GstBaseSink * bsink, GstBufferList * list)
         ret = sendmsg (*client->sock, &msg, 0);
 
         if (ret < 0) {
-          if (errno != EINTR && errno != EAGAIN) {
+          if (!socket_error_is_ignorable ()) {
             break;
           }
         } else {
@@ -597,12 +650,16 @@ gst_multiudpsink_setup_qos_dscp (GstMultiUDPSink * sink)
   tos = (sink->qos_dscp & 0x3f) << 2;
 
   if (setsockopt (sink->sock, IPPROTO_IP, IP_TOS, &tos, sizeof (tos)) < 0) {
-    GST_ERROR_OBJECT (sink, "could not set TOS: %s", g_strerror (errno));
+    gchar *errormessage = socket_last_error_message ();
+    GST_ERROR_OBJECT (sink, "could not set TOS: %s", errormessage);
+    g_free (errormessage);
   }
 #ifdef IPV6_TCLASS
   if (setsockopt (sink->sock, IPPROTO_IPV6, IPV6_TCLASS, &tos,
           sizeof (tos)) < 0) {
-    GST_ERROR_OBJECT (sink, "could not set TCLASS: %s", g_strerror (errno));
+    gchar *errormessage = socket_last_error_message ();
+    GST_ERROR_OBJECT (sink, "could not set TCLASS: %s", errormessage);
+    g_free (errormessage);
   }
 #endif
 }
@@ -635,6 +692,9 @@ gst_multiudpsink_set_property (GObject * object, guint prop_id,
     case PROP_TTL:
       udpsink->ttl = g_value_get_int (value);
       break;
+    case PROP_TTL_MC:
+      udpsink->ttl_mc = g_value_get_int (value);
+      break;
     case PROP_LOOP:
       udpsink->loop = g_value_get_boolean (value);
       break;
@@ -682,6 +742,9 @@ gst_multiudpsink_get_property (GObject * object, guint prop_id, GValue * value,
     case PROP_TTL:
       g_value_set_int (value, udpsink->ttl);
       break;
+    case PROP_TTL_MC:
+      g_value_set_int (value, udpsink->ttl_mc);
+      break;
     case PROP_LOOP:
       g_value_set_boolean (value, udpsink->loop);
       break;
@@ -694,6 +757,67 @@ gst_multiudpsink_get_property (GObject * object, guint prop_id, GValue * value,
   }
 }
 
+static gboolean
+gst_multiudpsink_configure_client (GstMultiUDPSink * sink,
+    GstUDPClient * client)
+{
+  GST_DEBUG_OBJECT (sink, "configuring client %p", client);
+
+  if (gst_udp_is_multicast (&client->theiraddr)) {
+    GST_DEBUG_OBJECT (sink, "we have a multicast client %p", client);
+    if (sink->auto_multicast) {
+      GST_DEBUG_OBJECT (sink, "autojoining group");
+      if (gst_udp_join_group (*(client->sock), &client->theiraddr, NULL)
+          != 0)
+        goto join_group_failed;
+    }
+    GST_DEBUG_OBJECT (sink, "setting loop to %d", sink->loop);
+    if (gst_udp_set_loop (sink->sock, sink->ss_family, sink->loop) != 0)
+      goto loop_failed;
+    GST_DEBUG_OBJECT (sink, "setting ttl to %d", sink->ttl_mc);
+    if (gst_udp_set_ttl (sink->sock, sink->ss_family, sink->ttl_mc, TRUE) != 0)
+      goto ttl_failed;
+  } else {
+    GST_DEBUG_OBJECT (sink, "setting unicast ttl to %d", sink->ttl);
+    if (gst_udp_set_ttl (sink->sock, sink->ss_family, sink->ttl, FALSE) != 0)
+      goto ttl_failed;
+  }
+  return TRUE;
+
+  /* ERRORS */
+join_group_failed:
+  {
+    gchar *errormessage = socket_last_error_message ();
+    int errorcode = socket_last_error_code ();
+    CLOSE_IF_REQUESTED (sink);
+    GST_ELEMENT_ERROR (sink, RESOURCE, SETTINGS, (NULL),
+        ("Could not join multicast group (%d): %s", errorcode, errormessage));
+    g_free (errormessage);
+    return FALSE;
+  }
+ttl_failed:
+  {
+    gchar *errormessage = socket_last_error_message ();
+    int errorcode = socket_last_error_code ();
+    CLOSE_IF_REQUESTED (sink);
+    GST_ELEMENT_ERROR (sink, RESOURCE, SETTINGS, (NULL),
+        ("Could not set TTL socket option (%d): %s", errorcode, errormessage));
+    g_free (errormessage);
+    return FALSE;
+  }
+loop_failed:
+  {
+    gchar *errormessage = socket_last_error_message ();
+    int errorcode = socket_last_error_code ();
+    CLOSE_IF_REQUESTED (sink);
+    GST_ELEMENT_ERROR (sink, RESOURCE, SETTINGS, (NULL),
+        ("Could not set loopback socket option (%d): %s",
+            errorcode, errormessage));
+    g_free (errormessage);
+    return FALSE;
+  }
+}
+
 /* create a socket for sending to remote machine */
 static gboolean
 gst_multiudpsink_init_send (GstMultiUDPSink * sink)
@@ -703,13 +827,32 @@ gst_multiudpsink_init_send (GstMultiUDPSink * sink)
   GstUDPClient *client;
 
   if (sink->sockfd == -1) {
+    GST_DEBUG_OBJECT (sink, "creating sockets");
     /* create sender socket try IP6, fall back to IP4 */
-    if ((sink->sock = socket (AF_INET6, SOCK_DGRAM, 0)) == -1)
+    sink->ss_family = AF_INET6;
+    if ((sink->sock = socket (AF_INET6, SOCK_DGRAM, 0)) == -1) {
+      sink->ss_family = AF_INET;
       if ((sink->sock = socket (AF_INET, SOCK_DGRAM, 0)) == -1)
         goto no_socket;
+    }
 
+    GST_DEBUG_OBJECT (sink, "have socket");
     sink->externalfd = FALSE;
   } else {
+    struct sockaddr_storage myaddr;
+#ifdef G_OS_WIN32
+    gint len;
+#else
+    guint len;
+#endif
+
+    GST_DEBUG_OBJECT (sink, "using configured socket");
+    /* we use the configured socket, try to get some info about it */
+    len = sizeof (myaddr);
+    if (getsockname (sink->sockfd, (struct sockaddr *) &myaddr, &len) < 0)
+      goto getsockname_error;
+
+    sink->ss_family = myaddr.ss_family;
     /* we use the configured socket */
     sink->sock = sink->sockfd;
     sink->externalfd = TRUE;
@@ -723,30 +866,46 @@ gst_multiudpsink_init_send (GstMultiUDPSink * sink)
   sink->bytes_to_serve = 0;
   sink->bytes_served = 0;
 
-  gst_udp_set_loop_ttl (sink->sock, sink->loop, sink->ttl);
   gst_multiudpsink_setup_qos_dscp (sink);
 
-  /* look for multicast clients and join multicast groups appropriately */
+  /* look for multicast clients and join multicast groups appropriately
+     set also ttl and multicast loopback delivery appropriately  */
   for (clients = sink->clients; clients; clients = g_list_next (clients)) {
     client = (GstUDPClient *) clients->data;
-    if (sink->auto_multicast && gst_udp_is_multicast (&client->theiraddr))
-      gst_udp_join_group (*(client->sock), &client->theiraddr, NULL);
+
+    if (!gst_multiudpsink_configure_client (sink, client))
+      return FALSE;
   }
   return TRUE;
 
   /* ERRORS */
 no_socket:
   {
+    gchar *errormessage = socket_last_error_message ();
+    int errorcode = socket_last_error_code ();
     GST_ELEMENT_ERROR (sink, RESOURCE, FAILED, (NULL),
-        ("Could not create socket (%d): %s", errno, g_strerror (errno)));
+        ("Could not create socket (%d): %s", errorcode, errormessage));
+    g_free (errormessage);
+    return FALSE;
+  }
+getsockname_error:
+  {
+    gchar *errormessage = socket_last_error_message ();
+    int errorcode = socket_last_error_code ();
+    GST_ELEMENT_ERROR (sink, RESOURCE, FAILED, (NULL),
+        ("Could not getsockname (%d): %s", errorcode, errormessage));
+    g_free (errormessage);
     return FALSE;
   }
 no_broadcast:
   {
+    gchar *errormessage = socket_last_error_message ();
+    int errorcode = socket_last_error_code ();
     CLOSE_IF_REQUESTED (sink);
     GST_ELEMENT_ERROR (sink, RESOURCE, SETTINGS, (NULL),
-        ("Could not set broadcast socket option (%d): %s", errno,
-            g_strerror (errno)));
+        ("Could not set broadcast socket option (%d): %s",
+            errorcode, errormessage));
+    g_free (errormessage);
     return FALSE;
   }
 }
@@ -777,16 +936,7 @@ gst_multiudpsink_add_internal (GstMultiUDPSink * sink, const gchar * host,
   client->connect_time = GST_TIMEVAL_TO_TIME (now);
 
   if (*client->sock > 0) {
-    /* check if its a multicast address */
-    if (gst_udp_is_multicast (&client->theiraddr)) {
-      GST_DEBUG_OBJECT (sink, "multicast address detected");
-      if (sink->auto_multicast) {
-        GST_DEBUG_OBJECT (sink, "joining multicast group");
-        gst_udp_join_group (*(client->sock), &client->theiraddr, NULL);
-      }
-    } else {
-      GST_DEBUG_OBJECT (sink, "normal address detected");
-    }
+    gst_multiudpsink_configure_client (sink, client);
   }
 
   if (lock)
