@@ -82,6 +82,7 @@ struct _GstVideoMixer
   gint numpads;
 
   GstClockTime last_ts;
+  GstClockTime last_duration;
 
   /* the master pad */
   GstVideoMixerPad *master;
@@ -97,7 +98,7 @@ struct _GstVideoMixer
 
   gint fps_n;
   gint fps_d;
-  
+
   /* Next available sinkpad index */
   gint next_sinkpad;
 
@@ -115,6 +116,8 @@ struct _GstVideoMixer
   BlendFunction blend;
   FillCheckerFunction fill_checker;
   FillColorFunction fill_color;
+
+  gboolean flush_stop_pending;
 };
 
 struct _GstVideoMixerClass
@@ -122,5 +125,7 @@ struct _GstVideoMixerClass
   GstElementClass parent_class;
 };
 
+GType gst_video_mixer_get_type (void);
+
 G_END_DECLS
 #endif /* __GST_VIDEO_MIXER_H__ */
