@@ -52,15 +52,6 @@
 GST_DEBUG_CATEGORY_STATIC (gst_debug_ximage_src);
 #define GST_CAT_DEFAULT gst_debug_ximage_src
 
-/* elementfactory information */
-static const GstElementDetails ximagesrc_details =
-GST_ELEMENT_DETAILS ("Ximage video source",
-    "Source/Video",
-    "Creates a screenshot video stream",
-    "Lutz Mueller <lutz@users.sourceforge.net>, "
-    "Jan Schmidt <thaytan@mad.scientist.com>, "
-    "Zaheer Merali <zaheerabbas at merali dot org>");
-
 static GstStaticPadTemplate t =
 GST_STATIC_PAD_TEMPLATE ("src", GST_PAD_SRC, GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("video/x-raw-rgb, "
@@ -525,7 +516,6 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
       memcpy (GST_BUFFER_DATA (GST_BUFFER (ximage)),
           GST_BUFFER_DATA (GST_BUFFER (ximagesrc->last_ximage)),
           GST_BUFFER_SIZE (GST_BUFFER (ximage)));
-      have_frame = TRUE;
     }
 #ifdef HAVE_XFIXES
     /* re-get area where last mouse pointer was  but only if in our clipping
@@ -619,7 +609,6 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
     if (ximagesrc->cursor_image != NULL) {
       int cx, cy, i, j, count;
       int startx, starty, iwidth, iheight;
-      gboolean clipped = FALSE;
       gboolean cursor_in_image = TRUE;
 
       cx = ximagesrc->cursor_image->x - ximagesrc->cursor_image->xhot;
@@ -653,7 +642,6 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
           iheight = (cy + ximagesrc->cursor_image->height < ximagesrc->endy) ?
               cy + ximagesrc->cursor_image->height - starty :
               ximagesrc->endy - starty;
-          clipped = TRUE;
         }
       } else {
         startx = cx;
@@ -901,7 +889,12 @@ gst_ximage_src_base_init (gpointer g_class)
 {
   GstElementClass *ec = GST_ELEMENT_CLASS (g_class);
 
-  gst_element_class_set_details (ec, &ximagesrc_details);
+  gst_element_class_set_details_simple (ec, "Ximage video source",
+      "Source/Video",
+      "Creates a screenshot video stream",
+      "Lutz Mueller <lutz@users.sourceforge.net>, "
+      "Jan Schmidt <thaytan@mad.scientist.com>, "
+      "Zaheer Merali <zaheerabbas at merali dot org>");
   gst_element_class_add_pad_template (ec, gst_static_pad_template_get (&t));
 }
 
@@ -933,7 +926,7 @@ gst_ximage_src_get_caps (GstBaseSrc * bs)
 {
   GstXImageSrc *s = GST_XIMAGE_SRC (bs);
   GstXContext *xcontext;
-  gint x, y, width, height;
+  gint width, height;
 
   if ((!s->xcontext) && (!gst_ximage_src_open_display (s, s->display_name)))
     return
@@ -947,7 +940,6 @@ gst_ximage_src_get_caps (GstBaseSrc * bs)
 
   xcontext = s->xcontext;
 
-  x = y = 0;
   width = xcontext->width;
   height = xcontext->height;
   if (s->endx > s->startx && s->endy > s->starty) {
@@ -955,8 +947,6 @@ gst_ximage_src_get_caps (GstBaseSrc * bs)
     if (s->startx < xcontext->width && s->endx < xcontext->width &&
         s->starty < xcontext->height && s->endy < xcontext->height) {
       /* values are fine */
-      x = s->startx;
-      y = s->starty;
       s->width = width = s->endx - s->startx;
       s->height = height = s->endy - s->starty;
     } else {
@@ -1123,6 +1113,7 @@ gst_ximage_src_class_init (GstXImageSrcClass * klass)
 static void
 gst_ximage_src_init (GstXImageSrc * ximagesrc, GstXImageSrcClass * klass)
 {
+  gst_base_src_set_format (GST_BASE_SRC (ximagesrc), GST_FORMAT_TIME);
   gst_base_src_set_live (GST_BASE_SRC (ximagesrc), TRUE);
   gst_pad_set_fixatecaps_function (GST_BASE_SRC_PAD (ximagesrc),
       gst_ximage_src_fixate);
